==> Master Update v4.8.0.3.zip: Master Update GX v4.8.0.3/Shopsystem/Dateien/lang/english/original_sections/admin/emails.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	emails.lang.inc.php 2022-05-14
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2022 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'bulk_delete_selected'                       => 'Delete',
    'bulk_send_selected'                         => 'Send',
    'delete_old_attachments'                     => 'Delete old attachments',
    'delete_old_emails'                          => 'Delete old emails',
    'email'                                      => 'Email',
    'emails'                                     => 'Emails',
    'email_html'                                 => 'HTML',
    'email_pending'                              => 'Pending',
    'email_plain'                                => 'Plain',
    'email_recipient'                            => 'Recipient',
    'email_reply_to'                             => 'Reply To',
    'email_sender'                               => 'Sender',
    'email_sent'                                 => 'Sent',
    'email_subject'                              => 'Subject',
    'attachments_size_loading'                   => 'is being determined',
    'handle_attachments'                         => 'Delete old attachments',
    'handle_old_emails'                          => 'Delete old emails',
    'message_attachment_could_not_be_found'      => 'Email could not be sent because the following attachment is missing: ',
    'message_delete_old_attachments_description' => 'Please select a date up to which the old attachments should be deleted.',
    'message_delete_old_attachments_success'     => 'Attachments were deleted successfully!',
    'message_delete_old_emails_description'      => 'Please select a date up to which the old emails should be deleted.',
    'message_delete_old_emails_notice'           => 'Please mind before deleting emails, the legal storage periods for business documents!',
    'message_delete_old_emails_success'          => 'Emails were deleted successfully!',
    'message_download_attachment_error'          => 'Attachment could not be found.',
    'message_remove_attachment_error'            => 'Could not remove file. Server responded with the following message: ',
    'message_upload_attachment_error'            => 'Could not upload file. Server responded with the following message: ',
    'modal_attachments'                          => 'Attachments',
    'modal_contact_email'                        => 'Email',
    'modal_contact_name'                         => 'Name',
    'modal_contact_type'                         => 'Type',
    'modal_details'                              => 'Details',
    'modal_path'                                 => 'Path',
    'modal_upload_attachment'                    => 'Upload Attachment',
    'name'                                       => 'Name',
    'prompt_delete_collection'                   => 'Do you want to delete selected emails?',
    'prompt_delete_email'                        => 'Do you want to delete this mail?',
    'prompt_delete_old_attachments'              => 'Do you want to delete attachments prior to the selected date?',
    'prompt_delete_old_emails'                   => 'Do you want to delete emails prior to the selected date?',
    'prompt_send_collection'                     => 'Do you want to send selected emails?',
    'prompt_send_email'                          => 'Do you want to send this mail?',
    'removal_date'                               => 'Removal Date',
    'table_actions'                              => 'Actions',
    'table_creation'                             => 'Creation',
    'table_status'                               => 'Status',
    'size'                                          => 'Size:'
];

==> Master Update v5.0.0.0.zip: Master Update GX v5.0.0.0/Shopsystem/Dateien/lang/english/original_sections/admin/emails.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	emails.lang.inc.php 2023-11-24
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2023 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'bulk_delete_selected'                       => 'Delete',
    'bulk_send_selected'                         => 'Send',
    'delete_old_attachments'                     => 'Delete old attachments',
    'delete_old_emails'                          => 'Delete old emails',
    'email'                                      => 'Email',
    'emails'                                     => 'Emails',
    'email_html'                                 => 'HTML',
    'email_pending'                              => 'Pending',
    'email_plain'                                => 'Plain',
    'email_recipient'                            => 'Recipient',
    'email_reply_to'                             => 'Reply To',
    'email_sender'                               => 'Sender',
    'email_sent'                                 => 'Sent',
    'email_subject'                              => 'Subject',
    'attachments_size_loading'                   => 'is being determined',
    'handle_attachments'                         => 'Delete old attachments',
    'handle_old_emails'                          => 'Delete old emails',
    'message_attachment_could_not_be_found'      => 'Email could not be sent because the following attachment is missing: ',
    'message_delete_old_attachments_description' => 'Please select a date up to which the old attachments should be deleted.',
    'message_delete_old_attachments_success'     => 'Attachments were deleted successfully!',
    'message_delete_old_emails_description'      => 'Please select a date up to which the old emails should be deleted.',
    'message_delete_old_emails_notice'           => 'Please mind before deleting emails, the legal storage periods for business documents!',
    'message_delete_old_emails_success'          => 'Emails were deleted successfully!',
    'message_download_attachment_error'          => 'Attachment could not be found.',
    'message_remove_attachment_error'            => 'Could not remove file. Server responded with the following message: ',
    'message_upload_attachment_error'            => 'Could not upload file. Server responded with the following message: ',
    'modal_attachments'                          => 'Attachments',
    'modal_contact_email'                        => 'Email',
    'modal_contact_name'                         => 'Name',
    'modal_contact_type'                         => 'Type',
    'modal_details'                              => 'Details',
    'modal_path'                                 => 'Path',
    'modal_upload_attachment'                    => 'Upload Attachment',
    'name'                                       => 'Name',
    'prompt_delete_collection'                   => 'Do you want to delete selected emails?',
    'prompt_delete_email'                        => 'Do you want to delete this mail?',
    'prompt_delete_old_attachments'              => 'Do you want to delete attachments prior to the selected date?',
    'prompt_delete_old_emails'                   => 'Do you want to delete emails prior to the selected date?',
    'prompt_send_collection'                     => 'Do you want to send selected emails?',
    'prompt_send_email'                          => 'Do you want to send this mail?',
    'removal_date'                               => 'Removal Date',
    'table_actions'                              => 'Actions',
    'table_creation'                             => 'Creation',
    'table_status'                               => 'Status',
    'size'                                       => 'Size:',
    'outbound_email_body'                        => "This is a redirected email.<br/><br/>During the 14-day test phase, all emails that your store sends to your customers will be redirected to your email address. As soon as you have selected one of our cloud tariffs and concluded a contract, your store will be able to send emails as normal.",
];
